import React, { useState } from 'react';
import Styled from 'styled-components';

const TagInputWODrop = ({ type, placeholder, error, setUpdateList }) => {
  const [tags, setTags] = useState([]);
  const [tempTag, setTempTag] = useState('');
  /**
   * Add the value to the list of tags
   * @param {*} value
   */

  const onAddtag = value => {
    const copyTags = [...tags];
    copyTags.push(value);
    setTags(copyTags);
    setUpdateList(copyTags);
  };
  /**
   * Use index to track the value to be deleted
   * @param {*} index
   */

  const onDeleteTag = index => {
    const copyTags = [...tags];
    copyTags.splice(index, 1);
    setTags(copyTags);
  };

  return /*#__PURE__*/ React.createElement(
    React.Fragment,
    null,
    /*#__PURE__*/ React.createElement(
      Inputwrapper,
      {
        className: `input-wrapper tag-wrapper ${error ? 'input-error' : ''}`,
      },
      /*#__PURE__*/ React.createElement(
        TagInputWrapper,
        {
          className: 'tag-input active',
        },
        tags?.map((tag, i) => {
          return /*#__PURE__*/ React.createElement(
            Tag,
            {
              key: i,
            },
            /*#__PURE__*/ React.createElement('span', null, tag),
            /*#__PURE__*/ React.createElement(
              'svg',
              {
                style: {
                  cursor: 'pointer',
                },
                onClick: () => onDeleteTag(i),
              },
              /*#__PURE__*/ React.createElement('use', {
                href: '/images/icons.svg#cancel',
              })
            )
          );
        }),
        /*#__PURE__*/ React.createElement('input', {
          value: tempTag,
          onChange: e => {
            if (e.target.value !== ',') {
              setTempTag(e.target.value);
            }
          },
          onKeyDown: e => {
            if (e.key === ',' || e.key === 'Enter') {
              onAddtag(e.target.value);
              setTempTag('');
            }
          },
          type: type,
          placeholder: placeholder,
        })
      ),
      error
        ? /*#__PURE__*/ React.createElement(
            'p',
            {
              className: 'error-message',
            },
            'Uh oh! There was an error!'
          )
        : null
    )
  );
};

export default TagInputWODrop;
const TagInputWrapper = Styled.div`
    position: relative;
    background: #F1F1F4;
    padding: 0.7rem 0.8rem;
    padding-right: 119px;
    min-height: 53px;
    z-index: 1;
    display: flex;
    flex-wrap: wrap;
    align-content: flex-start;
    flex-grow: 1; 
    
    &:before {
        content: "";
        position: absolute;
        left: 0;
        bottom: 0;
        display: block;
        width: 0;
        height: 2px;
        transition: width 1s ease;
        z-index: 2;
    }
    &:after {
        content: "";
        position: absolute;
        left: 0;
        bottom: 0;
        display: block;
        width: 100%;
        height: 2px;
        background: #C5C9DA;
    }
    &:focus-within{
        &:before {
            background: var(--co-primary);
            width: 100%;
        }
    }
    &.active{
        &:before {
            background: var(--co-primary);
            width: 100%;
        }
    }
    input{
        margin-left: 1rem;
        heigh: 30px;
    }
    .dropwrapper{
        position: absolute;
        right: 0;
        top: 50%;
        transform: translateY(-50%);
        z-index: 4;

    }
`;
const Tag = Styled.div`
    display: flex;
    align-items: center;
    background: #C5C9DA;
    border-radius: 3px;
    min-width: 119px;
    padding: 1rem 0.5rem;
    margin-right: 0.5rem;
    margin-bottom: 0.5rem;
    span{
        color: var(--co-head);
        font-family: var(--ff-sbold);
        font-weight: 600;
        margin-right: 1rem;
        font-size: 1.2rem;
    }
    svg{
        width: 12px;
        height: 12px;
        color:  #61677C;
    }
`;
const Inputwrapper = Styled.div`
 position: relative;
    &.input-w-label{
        .input{
            padding-top: 1.5rem;
            padding-bottom: 1.5rem;
        }
        input{
            padding-top: 0
            
        }
    }
    .main-label{
        display: flex;
        align-items: center;
        font-size: 1.2rem;
        color: #838CA2;
        font-family: var(--ff-sbold);
        font-weight: 600;
        margin-bottom: 1.2rem;
        svg{
            width: 15px;
            height: 15px;
            margin-left: 0.5rem;
        }
    }
    .error-message{
        font-size: 1.2rem;
        font-family: var(--ff-medium);
        color: var(--co-error);
        line-height: 1.1;
        margin-top: 1rem;
    }
    &.input-error{
        .label{ 
            color: var(--co-error);
            span{
                opacity: 1;
                transform: translateY(0); 
            }
            &:before{
                background: var(--co-error);
                width: 100%;
            }
        }
        .input{
            border-color: var(--co-error);
        }
        .label:before {
            background: var(--co-error);
            width: 100%;
        }
        
        input:not(:placeholder-shown) ~ .label:before, textarea:not(:placeholder-shown) ~ .label:before {
            background: var(--co-error);
            width: 100%;
        }
        .input:focus-within{
        .label{
            opacity: 1;
            border-bottom: none
        }
        .label:before {
            background: var(--co-error);
            width: 100%;
        }
    }
        
    }
    &:not(:last-child):not(:only-child){
        margin-bottom: 4rem ;
    }
    &.tag-wrapper{
       margin-bottom: 1rem;
       &:not(:last-child):not(:only-child){
        margin-bottom: 2rem ;
       
        }
    }
`;
