import React from 'react';
import FadeIn from 'react-fade-in';
import styled from 'styled-components';
import { PrimaryIconButton } from '../../../components/common/buttons/IconButton';
import { FbDropElement } from '../../../components/common/inputs/Select';
import { BasicSwitch } from '../../../components/common/inputs/Switch';
import {
  FbQuestionInput,
  InputWOLabel,
} from '../../../components/common/inputs/TextInput';
import { FormFieldWrapper } from '../../../containers/form-containers/FormBuilderLayouts';
import { connect } from 'react-redux';
import {
  setActiveElement,
  editElementLabel,
  editElementDescription,
  setMinMaxChars,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
  uploadElementImage,
  getUploadUrl,
  removeElementImage,
} from '../../../redux/action-creators/form-builder-actions/form-builder.actions';

const FileUpload = ({
  setActiveElement,
  activeElement,
  serialNumber,
  elementDetails,
  editElementLabel,
  editElementDescription,
  index,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
}) => {
  const onToggleRequired = () => {
    toggleAction('isMandatory');
  };

  const onToggleHidden = () => {
    toggleAction('hidden');
  };

  const switchElement = type => {
    changeFormElement(type, index);
  };

  return /*#__PURE__*/ React.createElement(
    FormFieldWrapper,
    {
      onclick: () => setActiveElement(elementDetails.unique_id),
      className: elementDetails.unique_id === activeElement ? 'active' : '',
    },
    /*#__PURE__*/ React.createElement(
      FadeIn,
      null,
      /*#__PURE__*/ React.createElement(
        'div',
        {
          className: 'form-field-settings',
        },
        /*#__PURE__*/ React.createElement(
          'div',
          {
            className: 'form-field-question mb-3',
          },
          /*#__PURE__*/ React.createElement(
            QuestionTag,
            {
              className: 'question-tag ',
            },
            /*#__PURE__*/ React.createElement(
              'svg',
              {
                className: 'bg-svg',
              },
              /*#__PURE__*/ React.createElement('use', {
                href: '/images/icons.svg#fb-file-upload',
              })
            ),
            /*#__PURE__*/ React.createElement(
              'span',
              null,
              'Q',
              serialNumber + 1
            )
          ),
          /*#__PURE__*/ React.createElement(FbQuestionInput, {
            onchange: val => editElementLabel(val),
            value: elementDetails.label,
            placeholder: 'Enter Your Question Here',
          }),
          /*#__PURE__*/ React.createElement(FbDropElement, {
            type: elementDetails.type,
            onSelect: switchElement,
          })
        ),
        /*#__PURE__*/ React.createElement(
          'div',
          {
            className: 'inputwo-label-wrap mb-3',
          },
          /*#__PURE__*/ React.createElement(InputWOLabel, {
            maxLength: 250,
            value: elementDetails.description,
            onchange: value => editElementDescription(value),
            placeholder: 'Add Your Description Here',
          }),
          /*#__PURE__*/ React.createElement(
            Instruction,
            null,
            'Maximum file size allowed - 1MB'
          )
        ),
        /*#__PURE__*/ React.createElement(
          'div',
          {
            className: 'd-flx-alc-jfe form-field-settings-footer',
          },
          /*#__PURE__*/ React.createElement(BasicSwitch, {
            checked: elementDetails.isMandatory,
            title: 'Required',
            onchange: onToggleRequired,
            className: 'mr-2',
          }),
          /*#__PURE__*/ React.createElement(BasicSwitch, {
            onchange: onToggleHidden,
            checked: elementDetails.hidden,
            title: 'Hidden',
            className: 'mr-2',
          }),
          /*#__PURE__*/ React.createElement(
            'span',
            {
              onClick: () => duplicateElement(elementDetails, index),
            },
            /*#__PURE__*/ React.createElement(PrimaryIconButton, {
              title: 'Duplicate',
              svg: 'duplicate',
              className: 'mr-2',
              color: '#61677C',
            })
          ),
          /*#__PURE__*/ React.createElement(
            'span',
            {
              onClick: () => deleteFormElement(elementDetails.unique_id),
            },
            /*#__PURE__*/ React.createElement(PrimaryIconButton, {
              title: 'Delete',
              svg: 'delete-alt',
              color: '#61677C',
            })
          )
        )
      ),
      /*#__PURE__*/ React.createElement(
        'div',
        {
          className: 'form-field-preview',
        },
        /*#__PURE__*/ React.createElement(
          QuestionTag,
          {
            className: 'question-tag',
          },
          /*#__PURE__*/ React.createElement(
            'svg',
            {
              className: 'bg-svg',
            },
            /*#__PURE__*/ React.createElement('use', {
              href: '/images/icons.svg#fb-file-upload',
            })
          ),
          /*#__PURE__*/ React.createElement('span', null, 'Q', serialNumber + 1)
        ),
        /*#__PURE__*/ React.createElement(
          'div',
          {
            className: 'preview-content',
          },
          /*#__PURE__*/ React.createElement(
            'h4',
            null,
            elementDetails.label,
            ' ',
            elementDetails.isMandatory &&
              /*#__PURE__*/ React.createElement('span', null, '*')
          ),
          /*#__PURE__*/ React.createElement(
            'p',
            null,
            elementDetails.description
          ),
          /*#__PURE__*/ React.createElement(InputSample, null, 'Upload File')
        )
      )
    )
  );
};

const mapStateToProps = state => ({
  activeElement: state.formBuilder.activeElement,
  formData: state.formBuilder.formData,
  formName: state.formBuilder.name,
  activePage: state.formBuilder.activePage,
  activeView: state.formBuilder.activeView,
});

export default connect(mapStateToProps, {
  setActiveElement,
  editElementLabel,
  editElementDescription,
  setMinMaxChars,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
  uploadElementImage,
  getUploadUrl,
  removeElementImage,
})(FileUpload);
const InputSample = styled.div`
  background: #fff;
  height: 44px;
  margin-top: 2rem;
  border-radius: 4px;
  padding: 1.2rem 2.5rem;
  width: 140px;
  border: 1px solid #004bff;
  color: #004bff;
  font-family: var(--ff-heading);
`;
const Instruction = styled.p`
  color: #0a1045;
  font-family: (--ff-sbold);
  font-weight: 600;
  align-self: flex-start;
  position: absolute;
  right: 0;
  bottom: -2.5rem;
`;
const QuestionTag = styled.div`
  background: #fff1d9;
  padding: 0 0.85rem;
`;
