import React from 'react';
import styled from 'styled-components';
import FadeIn from 'react-fade-in';
import { PrimaryIconButton } from '../../../components/common/buttons/IconButton';
import { FbDropElement } from '../../../components/common/inputs/Select';
import { BasicSwitch } from '../../../components/common/inputs/Switch';
import {
  FbQuestionInput,
  InputWOLabel,
} from '../../../components/common/inputs/TextInput';
import { connect } from 'react-redux';
import {
  setActiveElement,
  editElementLabel,
  editElementDescription,
  setMinMaxChars,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
  uploadElementImage,
  getUploadUrl,
  removeElementImage,
} from '../../../redux/action-creators/form-builder-actions/form-builder.actions';
import { FormFieldWrapper } from '../../../containers/form-containers/FormBuilderLayouts';

const ImageCapture = ({
  setActiveElement,
  activeElement,
  serialNumber,
  elementDetails,
  editElementLabel,
  editElementDescription,
  index,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
}) => {
  const onToggleRequired = () => {
    toggleAction('isMandatory');
  };

  const onToggleHidden = () => {
    toggleAction('hidden');
  };

  const switchElement = type => {
    changeFormElement(type, index);
  };
  return (
    <FormFieldWrapper
      onclick={() => setActiveElement(elementDetails.unique_id)}
      className={elementDetails.unique_id === activeElement ? 'active' : ''}
    >
      <FadeIn>
        <div className="form-field-settings">
          <div className="form-field-question mb-3">
            <QuestionTag className="question-tag ">
              <svg className="bg-svg">
                <use href="/images/icons.svg#fb-image-capture"></use>
              </svg>
              <span>Q{serialNumber + 1}</span>
            </QuestionTag>
            <FbQuestionInput
              onchange={val => editElementLabel(val)}
              value={elementDetails.label}
              placeholder="Enter Your Question Here"
            />
            <FbDropElement
              type={elementDetails.type}
              onSelect={switchElement}
            />
          </div>
          <div className="inputwo-label-wrap mb-3">
            <InputWOLabel
              value={elementDetails.description}
              maxLength={250}
              onchange={value => editElementDescription(value)}
              placeholder="Add Your Description Here"
            />
            <Instruction>Maximum file size allowed - 1MB</Instruction>
          </div>

          <div className="d-flx-alc-jfe form-field-settings-footer">
            <BasicSwitch
              checked={elementDetails.isMandatory}
              title="Required"
              onchange={onToggleRequired}
              className="mr-2"
            />
            <BasicSwitch
              onchange={onToggleHidden}
              checked={elementDetails.hidden}
              title="Hidden"
              className="mr-2"
            />
            <span onClick={() => duplicateElement(elementDetails, index)}>
              <PrimaryIconButton
                title="Duplicate"
                svg="duplicate"
                className="mr-2"
                color="#61677C"
              />
            </span>
            <span onClick={() => deleteFormElement(elementDetails.unique_id)}>
              <PrimaryIconButton
                title="Delete"
                svg="delete-alt"
                color="#61677C"
              />
            </span>
          </div>
        </div>
        <div className="form-field-preview">
          <QuestionTag className="question-tag">
            <svg className="bg-svg">
              <use href="/images/icons.svg#fb-image-capture"></use>
            </svg>
            <span>Q{serialNumber + 1}</span>
          </QuestionTag>
          <div className="preview-content">
            <h4>
              {elementDetails.label}{' '}
              {elementDetails.isMandatory && <span>*</span>}
            </h4>
            <p>{elementDetails.description}</p>
            <InputSample>This element only works on mobile</InputSample>
          </div>
        </div>
      </FadeIn>
    </FormFieldWrapper>
  );
};

const mapStateToProps = state => ({
  activeElement: state.formBuilder.activeElement,
  formData: state.formBuilder.formData,
  formName: state.formBuilder.name,
  activePage: state.formBuilder.activePage,
  activeView: state.formBuilder.activeView,
});

export default connect(mapStateToProps, {
  setActiveElement,
  editElementLabel,
  editElementDescription,
  setMinMaxChars,
  toggleAction,
  duplicateElement,
  deleteFormElement,
  changeFormElement,
  uploadElementImage,
  getUploadUrl,
  removeElementImage,
})(ImageCapture);

const InputSample = styled.div`
  background: #e5ebff;
  height: 44px;
  margin-top: 2rem;
  border-radius: 10px;
  padding: 1.2rem 2.5rem;
  color: #002093;
  font-size: 1.6rem;
  max-width: 490px;
`;

const Instruction = styled.p`
  color: #0a1045;
  font-family: (--ff-sbold);
  font-weight: 600;
  align-self: flex-start;
  position: absolute;
  right: 0;
  bottom: -2.5rem;
`;

const QuestionTag = styled.div`
  background: #eaebef;
  padding: 0 0.85rem;
`;
